==> haskell-pango-0.13.5.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.5.0
id: pango-0.13.5.0-BKQct7kJ4SdIqpF8xrAg4A
key: pango-0.13.5.0-BKQct7kJ4SdIqpF8xrAg4A
license: LGPL-2.1-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
author: Axel Simon, Duncan Coutts
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
abi: 5f2d5f4f9b7b477fc4bb9f4dc72647ed
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
import-dirs: /usr/lib/ghc-8.6.1/site-local/pango-0.13.5.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/pango-0.13.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/pango-0.13.5.0
hs-libraries: HSpango-0.13.5.0-BKQct7kJ4SdIqpF8xrAg4A
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/cairo /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/lib/libffi-3.2.1/include
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/uuid /usr/include/pango-1.0
              /usr/include/fribidi
includes:
    hspango.h
depends:
    array-0.5.2.0 base-4.12.0.0 cairo-0.13.5.0-7xeCCqzGftQKFWKxwre3yE
    containers-0.6.0.1 directory-1.3.3.0
    glib-0.13.6.0-9WyksbQqaBrBk6GEam8kYQ mtl-2.2.2 pretty-1.1.3.6
    process-1.6.3.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pango-0.13.5.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pango.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pango
version: 0.13.5.0
id: pango-0.13.5.0-CVVhM6NMEmWHt5bSdoCmB9
key: pango-0.13.5.0-CVVhM6NMEmWHt5bSdoCmB9
license: LGPL-2.1-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
author: Axel Simon, Duncan Coutts
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the Pango text rendering engine.
description:
    This package provides a wrapper around the Pango C library that
    allows high-quality rendering of Unicode text. It can be used
    either with Cairo to output text in PDF, PS or other
    documents or with Gtk+ to display text on-screen.
category: Graphics
abi: 5f16bd1bd4cb6dbe72e7b088bd0f4154
exposed: True
exposed-modules:
    Graphics.Rendering.Pango Graphics.Rendering.Pango.Attributes
    Graphics.Rendering.Pango.BasicTypes Graphics.Rendering.Pango.Cairo
    Graphics.Rendering.Pango.Context Graphics.Rendering.Pango.Enums
    Graphics.Rendering.Pango.Font Graphics.Rendering.Pango.Layout
    Graphics.Rendering.Pango.Markup Graphics.Rendering.Pango.Rendering
    Graphics.Rendering.Pango.Structs Graphics.Rendering.Pango.Types
hidden-modules: Graphics.Rendering.Pango.GlyphStorage
                Graphics.Rendering.Pango.Description
import-dirs: /usr/lib/ghc-8.6.2/site-local/pango-0.13.5.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/pango-0.13.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/pango-0.13.5.0
hs-libraries: HSpango-0.13.5.0-CVVhM6NMEmWHt5bSdoCmB9
extra-libraries:
    pangocairo-1.0 cairo pango-1.0 gobject-2.0 glib-2.0
include-dirs: /usr/include/cairo /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/lib/libffi-3.2.1/include
              /usr/include/pixman-1 /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/uuid /usr/include/pango-1.0
              /usr/include/fribidi
includes:
    hspango.h
depends:
    array-0.5.3.0 base-4.12.0.0 cairo-0.13.5.0-4zJRc4zycl0eFd4SCw1hl
    containers-0.6.0.1 directory-1.3.3.0
    glib-0.13.6.0-9WyksbQqaBrBk6GEam8kYQ mtl-2.2.2 pretty-1.1.3.6
    process-1.6.3.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-pango/html/pango.haddock
haddock-html: /usr/share/doc/haskell-pango/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
